# Doc-strings

Doc-strings should be used to add in-code documentation of modules.

eg.
```
module MyModule:
    """
    This is a hiiiiigh quality module!
    """
```

This documentation not only helps you remember what you did, but also means your package is searchable and useable by others.